#include <iostream>
#include <iomanip>
#include <vector>
#include <array>

#include <algorithm>

using namespace std;

typedef long long ll;
typedef long double ld;

constexpr ll INF = 1e12;

struct st {
	ll x = 0;
	ll y = 0;

	st(ll x, ll y) :x(x), y(y) {}

	const st operator+(const st& val) const {
		return st(x + val.x, y + val.y);
	}

	const bool operator==(const st& val) const {
		return x == val.x && y == val.y;
	}

	const bool operator!=(const st& val) const {
		return x != val.x || y != val.y;
	}
};

array<st, 4> np = {
	st(0, -1),
	st(0, 1),
	st(-1, 0),
	st(1, 0)
};

ll n, m;

struct {
	vector<string> g;

	char& operator[](const st& val) {
		if (val.x < 0 || val.y < 0 || val.x > n + 1 || val.y > m + 1)
			while (1);
		return g[val.x][val.y];
	}

	string& operator[](const ll val) {
		return g[val];
	}
} g;


void dfs1(const st v) {
	if (g[v] != '.')
		return;

	g[v] = '!';

	for (auto& t : np) {
		st u = v + t;
		if (g[u] == '.')
			dfs1(u);
	}
}

bool okC(const st v, const char c) {
	for (auto& t : np) {
		st u = v + t;
		if (g[u] == c)
			return true;
	}
	return false;
}

bool dfsB(const st v, const st p);

bool dfsA(const st v, const st p) {
	g[v] = 'c';
	for (auto& t : np) {
		st u = v + t;
		if (u == p)
			continue;

		if (g[u] == 'c') {
			g[u] = 'y';
			return true;
		}
		if (g[u] == 'a' && dfsA(u, v)) {
			g[u] = 'y';
			return true;
		}
		if (g[u] == 'b' && dfsB(u, v)) {
			g[u] = 'y';
			return true;
		}
	}
	g[v] = '?';
	return false;
}

bool dfsB(const st v, const st p) {
	g[v] = 'c';
	for (auto& t : np) {
		st u = v + t;
		if (u == p)
			continue;

		if (g[u] == 'c') {
			g[u] = 'y';
			return true;
		}
		if (g[u] == 'a' && dfsA(u, v)) {
			g[u] = 'y';
			return true;
		}
	}
	g[v] = '?';
	return false;
}

void showRes() {
	for (ll i = 1; i <= n; ++i) {
		for (ll j = 1; j <= m; ++j) {
			if (g.g[i][j] == 'y')
				cout << "#";
			else
				cout << '.';
		}
		cout << '\n';
	}
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

	cin >> n >> m;
	g.g.resize(n + 2);
	g[0] = g[n + 1] = string(m + 2, '!');
	for (ll i = 1; i <= n; ++i) {
		cin >> g[i];
		g[i] = "!" + g[i] + "!";
	}

	for (ll i = 1; i <= n; ++i) {
		dfs1(st(i, 1));
		dfs1(st(i, m));
	}
	for (ll j = 1; j <= m; ++j) {
		dfs1(st(1, j));
		dfs1(st(n, j));
	}

	for (ll i = 1; i <= n; ++i) {
		for (ll j = 1; j <= m; ++j) {
			if (g.g[i][j] == '#' && okC(st(i, j), '.'))
				g.g[i][j] = 'a';
		}
	}
	for (ll i = 1; i <= n; ++i) {
		for (ll j = 1; j <= m; ++j) {
			if (g.g[i][j] == '#' && okC(st(i, j), 'a'))
				g.g[i][j] = 'b';
		}
	}

	for (ll i = 1; i <= n; ++i) {
		for (ll j = 1; j <= m; ++j) {
			if (g.g[i][j] == 'a') {
				bool ok = dfsA(st(i, j), st(0, 0));
				g.g[i][j] = 'y';

				showRes();
				return 0;
			}
		}
	}
}