#include <bits/stdc++.h>
using namespace std;
typedef long long ll;
typedef long double ld;

ld eps = 1e-7;

ostream& operator << (ostream& out, vector<int>& vec) {
    for (int el :vec) {
        out << el << ' ';
    }
    return out;
}

ostream& operator << (ostream& out, vector<bool>& vec) {
    for (bool el :vec) {
        if (el)
            out << '#';
        else
            out << '.';
    }
    return out;
}

template<typename T>
ostream& operator << (ostream& out, vector<T>& vec) {
    for (T el :vec) {
        out << el << '\n';
    }
    return out;
}


const int N = 1e5 + 10;
const int LOG_N = 20;
pair<int, int> sparse[LOG_N][N];
int lg2[N];

void build_table(vector<int>& a) {
    for (int i = 0; i < a.size(); ++i) {
        sparse[0][i] = make_pair(a[i], i);
    }
    lg2[0] = 0;
    lg2[1] = 0;
    for (int i = 2; i < N; ++i) {
        lg2[i] = lg2[i / 2] + 1;
    }
    for (int k = 1; k < LOG_N; ++k) {
        for (int i = 0; i + (1 << (k - 1)) < a.size(); ++i) {
            sparse[k][i] = min(sparse[k - 1][i], sparse[k - 1][i + (1 << (k - 1))]);
        }
    }
}

int get_min(int l, int r) {
    int lg = lg2[r - l + 1];
    return min(sparse[l][lg], sparse[r - (1 << lg) + 1][lg]).second;
}

const int dx[] = {1, 0, -1, 0, 1, 1, -1, -1};
const int dy[] = {0, 1, 0, -1, 1, -1, 1, -1};

int n, m;

bool can_get_away(int x, int y, vector<vector<bool>>& park, vector<vector<bool>>& used) {
    if (x < 0 || y < 0 || x == n || y == m)
        return true;
    if (used[x][y] || park[x][y])
        return false;
    used[x][y] = true;
    bool res = false;
    for (int i = 0; i < 4; ++i) {
        bool cur = can_get_away(x + dx[i], y + dy[i], park, used);
        res = (cur || res);
    }
    return res;
}

void match_lake(int x, int y, vector<vector<bool>>& park, vector<vector<bool>>& used, vector<vector<bool>>& lake) {
    if (x < 0 || y < 0 || x == n || y == m)
        return;
    if (park[x][y]) {
        lake[x][y] = true;
        return;
    }
    if (used[x][y])
        return;
    used[x][y] = true;
    for (int i = 0; i < 8; ++i) {
        match_lake(x + dx[i], y + dy[i], park, used, lake);
    }
}

const int INF = 1e9;

int get_vert(int i, int j) {
    return i * m + j;
}

void make_better(vector<vector<bool>>& lake) {
    vector<vector<int>> g(n * m);
    int s = -1;
    for (int i = 0; i < n && s == -1; ++i) {
        for (int j = 0; j < m; ++j) {
            if (lake[i][j]) {
                s = get_vert(i, j);
                break;
            }
        }
    }
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            if (!lake[i][j])
                continue;
            for (int k = 0; k < 4; ++k) {
                int nx = i + dx[k], ny = j + dy[k];
                if (nx < 0 || ny < 0 || nx == n || ny == m || !lake[nx][ny])
                    continue;
                g[get_vert(i, j)].push_back(get_vert(nx, ny));
            }
        }
    }
    vector<int> d(n * m, INF), par(n * m, -1);
    queue<int> q;
    d[s] = 0;
    q.push(g[s][0]); d[g[s][0]] = 1;
    while (!q.empty()) {
        int v = q.front();
        q.pop();
        for (int u :g[v]) {
            if (d[u] > d[v] + 1) {
                par[u] = v;
                d[u] = d[v] + 1;
                q.push(u);
            }
        }
    }
    int f = -1;
    for (int u :g[s]) {
        if (d[u] > 3) {
            f = u;
            break;
        }
    }
    vector<vector<bool>> ans(n, vector<bool> (m, false));
    while (f != -1) {
        ans[f / m][f % m] = true;
        f = par[f];
    }
    ans[s / m][s % m] = true;
    cout << ans;
}

int main() {
    ios_base::sync_with_stdio(false); cin.tie(nullptr); cout.tie(nullptr);
    //freopen("input.txt", "r", stdin);
    cin >> n >> m;
    vector<vector<bool>> park(n, vector<bool> (m, false));
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            char c;
            cin >> c;
            park[i][j] = (c == '#');
        }
    }
    vector<vector<bool>> used(n, vector<bool> (m, false));
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < m; ++j) {
            if (!used[i][j] && !park[i][j] && !can_get_away(i, j, park, used)) {
                used.clear();
                used.resize(n, vector<bool> (m, false));
                vector<vector<bool>> lake(n, vector<bool> (m, false));
                match_lake(i, j, park, used, lake);
                make_better(lake);
                return 0;
            }
        }
    }
}
